Crate barcode_gen

Crate barcode_gen 

A simple Code 128 barcode generator

Currently supports all features of Code 128.

Generating barcodes with FNC1, FNC2 and FNC3 is not possible however, since these are control characters that can’t appear in a normal string. FNC4 does work however and is switched to when needed automatically.

Structs

Barcode
A completed barcode.
BarcodeKey
The key used for [make_barcode_custom_table_dp]
Table
an encoding table, used to encode barcodes.
TableEntry
An entry in the encoding table.

Enums

BarcodeType
The different barcode types, used to keep track of the type used in the encoder.
BarcodeValue
A value in a barcode, consists of regular characters, digits for Code C, and control codes.

Constants

TABLE
const value of the most common table.

Functions

make_barcode
Make a barcode with the fastest available method
make_barcode_custom_table
Find a barcode using dynamic programming. It’s very fast. For the table parameter you can use TABLE, it’s the default table.
make_barcode_prefer_set
Makes a barcode with the fastest available method, prefering a specific codeset if both are equal.
make_barcode_string
Generate a barcode as a string.