BarcodeValue

Enum BarcodeValue 

pub enum BarcodeValue {
Show 15 variants RegularCharacter(char), Digit(u8), FNC1, FNC2, FNC3, FNC4, StartA, StartB, StartC, Stop, ShiftA, ShiftB, CodeA, CodeB, CodeC,
}
A value in a barcode, consists of regular characters, digits for Code C, and control codes.

Variants



RegularCharacter(char)

A regular character, also includes control characters.



Digit(u8)

A Code C digit, the numbers 0 through 9 are actually 00 through 09.



FNC1

Used to indicate a GS1-128 barcode



FNC2

Indicates that the currently scanned string should be prepended to the next scan



FNC3

Initialize, used for programming scanners



FNC4

Used for extended ASCII support.



StartA

The code used to signal we start in variant A



StartB

The code used to signal we start in variant B



StartC

The code used to signal we start in variant C



Stop

Not actually the stop code, just the one used at the end.



ShiftA

Use variant A for the next character



ShiftB

Use variant B for the next character



CodeA

Switch to variant A from here on out



CodeB

Switch to variant B from here on out



CodeC

Switch to variant C from here on out