pub fn make_barcode(text: &str) -> Option<Barcode<'_>>Expand description
Make a barcode with the fastest available method, currently uses make_barcode_custom_table_dp.
pub fn make_barcode(text: &str) -> Option<Barcode<'_>>Make a barcode with the fastest available method, currently uses make_barcode_custom_table_dp.