Struct TableEntry

pub struct TableEntry { /* private fields */ }
An entry in the encoding table.

Implementations

Source

impl TableEntry

pub fn new( value: u8, a: impl Into<BarcodeValue>, b: impl Into<BarcodeValue>, c: impl Into<BarcodeValue>, latin: char, ) -> Self

create a new table entry

pub fn value(&self) -> u8

the value of the entry, used for calculating the check digit

pub fn latin(&self) -> char

the most common character used to represent this value

pub fn barcode_bits(&self) -> u32

the bits used to encode the value on a normal barcode

pub fn barcode_runs(&self) -> &'static str

the runs for the code

A run of 1231 would mean 1001110 in binary