Structs
- Barcode
- A completed barcode.
- Barcode
Key - The key used for [
make_barcode_custom_table_dp] - Table
- an encoding table, used to encode barcodes.
- Table
Entry - An entry in the encoding table.
Enums
- Barcode
Type - The different barcode types, used to keep track of the type used in the encoder.
- Barcode
Value - A value in a barcode, consists of regular characters, digits for Code C, and control codes.
Constants
- TABLE
- const value of the most common table.
Functions
- make_
barcode - Make a barcode with the fastest available method
- make_
barcode_ custom_ table - Find a barcode using dynamic programming. It’s very fast.
For the table parameter you can use
TABLE, it’s the default table. - make_
barcode_ prefer_ set - Makes a barcode with the fastest available method, prefering a specific codeset if both are equal.
- make_
barcode_ string - Generate a barcode as a string.