Crate barcode_gen

Structs

Barcode
A completed barcode.
Table
an encoding table, used to encode barcodes.
TableEntry
An entry in the encoding table.

Enums

BarcodeType
The different barcode types, used to keep track of the type used in the encoder.
BarcodeValue
A value in a barcode, consists of regular characters, digits for Code C, and control codes.

Constants

TABLE
const value of the most common table.

Functions

make_barcode
Make a barcode with the fastest available method, currently uses make_barcode_custom_table_dp.
make_barcode_custom_table
Make a barcode using a custom table, you can provide TABLE to use the normal table.
make_barcode_custom_table_dp
Find a barcode using dynamic programming. It’s very fast.