Structs
- Barcode
- A completed barcode.
- Table
- an encoding table, used to encode barcodes.
- Table
Entry - An entry in the encoding table.
Enums
- Barcode
Type - The different barcode types, used to keep track of the type used in the encoder.
- Barcode
Value - A value in a barcode, consists of regular characters, digits for Code C, and control codes.
Constants
- TABLE
- const value of the most common table.
Functions
- make_
barcode - Make a barcode with the fastest available method.
- make_
barcode_ custom_ table - Make a barcode using a custom table, you can provide
TABLEto use the normal table. - make_
barcode_ custom_ table_ par - like
make_barcode_custom_table, but usesrayonto be up to 10 times faster.